.. hankel documentation master file, created by
   sphinx-quickstart on Mon Feb 13 10:17:24 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   example_toc
   license
   changelog
   authors
   contributing
   api



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
